/*
 * $Id$
 *
 * [ Description ]
 * 
 */

#include "Behavioural/Generic/Select/Priority_Fixed/include/Parameters.h"
#include "Behavioural/include/XML.h"
using namespace std;

namespace morpheo                    {
namespace behavioural {
namespace generic {
namespace select {
namespace priority_fixed {

  string Parameters::print (uint32_t depth)
  {
    log_printf(FUNC,Priority_Fixed,"print","Begin");

    XML xml ("priority_fixed");

    xml.balise_open("priority_fixed");
    xml.singleton_begin("nb_entity       "); xml.attribut("value",toString(_nb_entity       )); xml.singleton_end();
    xml.singleton_begin("encoding_one_hot"); xml.attribut("value",toString(_encoding_one_hot)); xml.singleton_end();
    xml.singleton_begin("encoding_compact"); xml.attribut("value",toString(_encoding_compact)); xml.singleton_end();
    xml.balise_close();

    log_printf(FUNC,Priority_Fixed,"print","End");
    
    return xml.get_body(depth);
  };

  ostream& operator<< (ostream& output_stream ,
		       morpheo::behavioural::generic::select::priority_fixed::Parameters & x)
  {
    output_stream << x.print(0);
    
    return output_stream;
  };

}; // end namespace priority_fixed
}; // end namespace select
}; // end namespace generic

}; // end namespace behavioural
}; // end namespace morpheo              
